==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QDataWidgetMapper_shell.h <==
#ifndef QDATAWIDGETMAPPER_SHELL_H
#define QDATAWIDGETMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(datawidgetmapper)
#include <QtWidgets/qdatawidgetmapper.h>
#endif //QT_CONFIG(datawidgetmapper)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(datawidgetmapper)

class QDataWidgetMapper_shell : public QDataWidgetMapper, public QtJambiShellInterface
{
public:
    QDataWidgetMapper_shell(QObject* parent0 = nullptr);
    ~QDataWidgetMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setCurrentIndex(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDataWidgetMapper_access : public QDataWidgetMapper
{
    void __qt_setCurrentIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QT_CONFIG(datawidgetmapper)
#endif // QDATAWIDGETMAPPER_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QDataWidgetMapper_shell.h <==
#ifndef QDATAWIDGETMAPPER_SHELL_H
#define QDATAWIDGETMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(datawidgetmapper)
#include <QtWidgets/qdatawidgetmapper.h>
#endif //QT_CONFIG(datawidgetmapper)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(datawidgetmapper)

class QDataWidgetMapper_shell : public QDataWidgetMapper, public QtJambiShellInterface
{
public:
    QDataWidgetMapper_shell(QObject* parent0 = nullptr);
    ~QDataWidgetMapper_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QDataWidgetMapper_mshell;
    friend class QDataWidgetMapper_oshell;
};


class QDataWidgetMapper_mshell : public QDataWidgetMapper_shell
{
public:
    using QDataWidgetMapper_shell::QDataWidgetMapper_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QDataWidgetMapper_oshell : public QDataWidgetMapper_mshell
{
public:
    using QDataWidgetMapper_mshell::QDataWidgetMapper_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setCurrentIndex(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDataWidgetMapper_access : public QDataWidgetMapper
{
    void __qt_setCurrentIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QT_CONFIG(datawidgetmapper)
#endif // QDATAWIDGETMAPPER_SHELL_H
